@@ -8,7 +8,7 @@ import urllib.parse
 import logging
 import sys
 
-from gen3.utils import append_query_params, DEFAULT_BACKOFF_SETTINGS
+from gen3.utils import append_query_params, DEFAULT_BACKOFF_SETTINGS, raise_for_status
 from gen3.auth import Gen3Auth
 
 
@@ -76,7 +76,7 @@ class Gen3Metadata:
             response = requests.get(
                 self.endpoint + "/_status", auth=self._auth_provider
             )
-            response.raise_for_status()
+            raise_for_status(response)
         except Exception as exc:
             logging.error(exc)
             return False
@@ -92,7 +92,7 @@ class Gen3Metadata:
             str: the version
         """
         response = requests.get(self.endpoint + "/version", auth=self._auth_provider)
-        response.raise_for_status()
+        raise_for_status(response)
         return response.text
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
@@ -106,7 +106,7 @@ class Gen3Metadata:
         response = requests.get(
             self.admin_endpoint + "/metadata_index", auth=self._auth_provider
         )
-        response.raise_for_status()
+        raise_for_status(response)
         return response.json()
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
@@ -120,7 +120,7 @@ class Gen3Metadata:
         response = requests.post(
             self.admin_endpoint + f"/metadata_index/{path}", auth=self._auth_provider
         )
-        response.raise_for_status()
+        raise_for_status(response)
         return response.json()
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
@@ -134,11 +134,19 @@ class Gen3Metadata:
         response = requests.delete(
             self.admin_endpoint + f"/metadata_index/{path}", auth=self._auth_provider
         )
-        response.raise_for_status()
+        raise_for_status(response)
         return response
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
-    def query(self, query, return_full_metadata=False, limit=10, offset=0, **kwargs):
+    def query(
+        self,
+        query,
+        return_full_metadata=False,
+        limit=10,
+        offset=0,
+        use_agg_mds=False,
+        **kwargs,
+    ):
         """
         Query the metadata given a query.
 
@@ -184,6 +192,7 @@ class Gen3Metadata:
             Dict{guid: {metadata}}: Dictionary with GUIDs as keys and associated
                 metadata JSON blobs as values
         """
+
         url = self.endpoint + f"/metadata?{query}"
 
         url_with_params = append_query_params(
@@ -191,7 +200,7 @@ class Gen3Metadata:
         )
         logging.debug(f"hitting: {url_with_params}")
         response = requests.get(url_with_params, auth=self._auth_provider)
-        response.raise_for_status()
+        raise_for_status(response)
 
         return response.json()
 
@@ -214,7 +223,7 @@ class Gen3Metadata:
             logging.debug(f"hitting: {url_with_params}")
 
             async with session.get(url_with_params, ssl=_ssl) as response:
-                response.raise_for_status()
+                raise_for_status(response)
                 response = await response.json()
 
         return response
@@ -235,7 +244,7 @@ class Gen3Metadata:
         url_with_params = append_query_params(url, **kwargs)
         logging.debug(f"hitting: {url_with_params}")
         response = requests.get(url_with_params, auth=self._auth_provider)
-        response.raise_for_status()
+        raise_for_status(response)
 
         return response.json()
 
@@ -268,7 +277,7 @@ class Gen3Metadata:
         response = requests.post(
             url_with_params, json=metadata_list, auth=self._auth_provider
         )
-        response.raise_for_status()
+        raise_for_status(response)
 
         return response.json()
 
@@ -291,7 +300,7 @@ class Gen3Metadata:
         response = requests.post(
             url_with_params, json=metadata, auth=self._auth_provider
         )
-        response.raise_for_status()
+        raise_for_status(response)
 
         return response.json()
 
@@ -318,7 +327,7 @@ class Gen3Metadata:
             async with session.post(
                 url_with_params, json=metadata, headers=headers, ssl=_ssl
             ) as response:
-                response.raise_for_status()
+                raise_for_status(response)
                 response = await response.json()
 
         return response
@@ -341,7 +350,7 @@ class Gen3Metadata:
         response = requests.put(
             url_with_params, json=metadata, auth=self._auth_provider
         )
-        response.raise_for_status()
+        raise_for_status(response)
 
         return response.json()
 
@@ -367,7 +376,7 @@ class Gen3Metadata:
             async with session.put(
                 url_with_params, json=metadata, headers=headers, ssl=_ssl
             ) as response:
-                response.raise_for_status()
+                raise_for_status(response)
                 response = await response.json()
 
         return response
@@ -385,6 +394,6 @@ class Gen3Metadata:
         url_with_params = append_query_params(url, **kwargs)
         logging.debug(f"hitting: {url_with_params}")
         response = requests.delete(url_with_params, auth=self._auth_provider)
-        response.raise_for_status()
+        raise_for_status(response)
 
         return response.json()
