@@ -3,6 +3,9 @@ import json
 import requests
 import pandas as pd
 import os
+import logging
+
+from gen3.utils import raise_for_status
 
 
 class Gen3Error(Exception):
@@ -53,7 +56,7 @@ class Gen3Submission:
         """List registered programs"""
         api_url = f"{self._endpoint}/api/v0/submission/"
         output = requests.get(api_url, auth=self._auth_provider)
-        output.raise_for_status()
+        raise_for_status(output)
         return output.json()
 
     def create_program(self, json):
@@ -68,7 +71,7 @@ class Gen3Submission:
         """
         api_url = "{}/api/v0/submission/".format(self._endpoint)
         output = requests.post(api_url, auth=self._auth_provider, json=json)
-        output.raise_for_status()
+        raise_for_status(output)
         return output.json()
 
     def delete_program(self, program):
@@ -87,7 +90,7 @@ class Gen3Submission:
         """
         api_url = "{}/api/v0/submission/{}".format(self._endpoint, program)
         output = requests.delete(api_url, auth=self._auth_provider)
-        output.raise_for_status()
+        raise_for_status(output)
         return output
 
     ### Project functions
@@ -106,7 +109,7 @@ class Gen3Submission:
         """
         api_url = f"{self._endpoint}/api/v0/submission/{program}"
         output = requests.get(api_url, auth=self._auth_provider)
-        output.raise_for_status()
+        raise_for_status(output)
         return output.json()
 
     def create_project(self, program, json):
@@ -122,7 +125,7 @@ class Gen3Submission:
         """
         api_url = "{}/api/v0/submission/{}".format(self._endpoint, program)
         output = requests.put(api_url, auth=self._auth_provider, json=json)
-        output.raise_for_status()
+        raise_for_status(output)
         return output.json()
 
     def delete_project(self, program, project):
@@ -142,7 +145,7 @@ class Gen3Submission:
         """
         api_url = "{}/api/v0/submission/{}/{}".format(self._endpoint, program, project)
         output = requests.delete(api_url, auth=self._auth_provider)
-        output.raise_for_status()
+        raise_for_status(output)
         return output
 
     def get_project_dictionary(self, program, project):
@@ -159,7 +162,7 @@ class Gen3Submission:
         """
         api_url = f"{self._endpoint}/api/v0/submission/{program}/{project}/_dictionary"
         output = requests.get(api_url, auth=self._auth_provider)
-        output.raise_for_status()
+        raise_for_status(output)
         return output.json()
 
     def open_project(self, program, project):
@@ -176,7 +179,7 @@ class Gen3Submission:
         """
         api_url = f"{self._endpoint}/api/v0/submission/{program}/{project}/open"
         output = requests.put(api_url, auth=self._auth_provider)
-        output.raise_for_status()
+        raise_for_status(output)
         return output.json()
 
     ### Record functions
@@ -196,6 +199,8 @@ class Gen3Submission:
 
         """
         api_url = "{}/api/v0/submission/{}/{}".format(self._endpoint, program, project)
+        logging.info("\nUsing the Sheepdog API URL {}\n".format(api_url))
+
         output = requests.put(api_url, auth=self._auth_provider, json=json)
         output.raise_for_status()
         return output.json()
@@ -243,7 +248,7 @@ class Gen3Submission:
                 auth=self._auth_provider,
             )
             try:
-                output.raise_for_status()
+                raise_for_status(output)
             except requests.exceptions.HTTPError:
                 print(
                     "\n{}\nFailed to delete uuids: {}".format(
@@ -341,7 +346,11 @@ class Gen3Submission:
         output = requests.get(api_url, auth=self._auth_provider).text
         if filename is None:
             if fileformat == "json":
-                output = json.loads(output)
+                try:
+                    output = json.loads(output)
+                except ValueError as e:
+                    print(f"Output: {output}\nUnable to parse JSON: {e}")
+                    raise
             return output
         else:
             self.__export_file(filename, output)
@@ -373,7 +382,11 @@ class Gen3Submission:
         output = requests.get(api_url, auth=self._auth_provider).text
         if filename is None:
             if fileformat == "json":
-                output = json.loads(output)
+                try:
+                    output = json.loads(output)
+                except ValueError as e:
+                    print(f"Output: {output}\nUnable to parse JSON: {e}")
+                    raise
             return output
         else:
             self.__export_file(filename, output)
