@@ -41,6 +41,7 @@ import copy
 import sys
 import traceback
 
+from gen3.index import Gen3Index
 from gen3.auth import Gen3Auth
 from gen3.tools.indexing.manifest_columns import (
     GUID_COLUMN_NAMES,
@@ -69,6 +70,7 @@ from gen3.utils import (
     SIZE_FORMAT,
     _verify_format,
     _standardize_str,
+    get_urls,
 )
 import indexclient.client as client
 from indexclient.client import Document
@@ -300,14 +302,7 @@ def _index_record(indexclient, replace_urls, thread_control, fi):
 
     try:
         urls = (
-            [
-                element.strip().replace("'", "").replace('"', "").replace("%20", " ")
-                for element in _standardize_str(fi[URLS_STANDARD_KEY])
-                .strip()
-                .lstrip("[")
-                .rstrip("]")
-                .split(" ")
-            ]
+            get_urls(fi[URLS_STANDARD_KEY])
             if URLS_STANDARD_KEY in fi
             and fi[URLS_STANDARD_KEY] != "[]"
             and fi[URLS_STANDARD_KEY]
@@ -443,6 +438,13 @@ def _index_record(indexclient, replace_urls, thread_control, fi):
                     new_guid = None
 
                 new_doc = Document(client=None, did=new_guid, json=record)
+
+                # TODO: in the case where a new GUID *is* provided AND a version with that
+                #       guid already exists AND you run this, it's gonna throw an error.
+                #       We need to gracefully handle the error from indexd. there will
+                #       be a conflict where a version with this GUID already exists...
+                #       but if we can verify that the version has the correct values
+                #       for all the fields, we can effectively ignore this error and continue
                 doc = indexclient.add_version(current_did=prev_guid, new_doc=new_doc)
             else:
                 logging.info(f"creating: {record}")
@@ -493,6 +495,7 @@ def index_object_manifest(
         auth(Gen3Auth): Gen3 auth or tuple with basic auth name and password
         replace_urls(bool): flag to indicate if replace urls or not
         manifest_file_delimiter(str): manifest's delimiter
+        output_filename(str): output file name for manifest
 
     Returns:
         files(list(dict)): list of file info
@@ -519,6 +522,8 @@ def index_object_manifest(
     if not commons_url.endswith(service_location):
         commons_url += "/" + service_location
 
+    logging.info("\nUsing URL {}\n".format(commons_url))
+
     indexclient = client.IndexClient(commons_url, "v0", auth=auth)
 
     # if delimter not specified, try to get based on file ext
@@ -643,3 +648,48 @@ if __name__ == "__main__":
     logging.basicConfig(filename="index_object_manifest.log", level=logging.DEBUG)
     logging.getLogger().addHandler(logging.StreamHandler(sys.stdout))
     index_object_manifest_cli()
+
+
+def delete_all_guids(auth, file):
+    """
+    Delete all GUIDs specified in the object manifest.
+
+    WARNING: THIS COMPLETELY REMOVES INDEX RECORDS. USE THIS ONLY IF YOU KNOW
+             THE IMPLICATIONS.
+    """
+    index = Gen3Index(auth.endpoint, auth_provider=auth)
+    if not index.is_healthy():
+        logging.debug(
+            f"uh oh! The indexing service is not healthy in the commons {auth.endpoint}"
+        )
+        exit()
+
+    # try to get delimeter based on file ext
+    file_ext = os.path.splitext(file)
+    if file_ext[-1].lower() == ".tsv":
+        manifest_file_delimiter = "\t"
+    else:
+        # default, assume CSV
+        manifest_file_delimiter = ","
+
+    with open(file, "r", encoding="utf-8-sig") as input_file:
+        csvReader = csv.DictReader(input_file, delimiter=manifest_file_delimiter)
+        fieldnames = csvReader.fieldnames
+
+        logging.debug(f"got fieldnames from {file}: {fieldnames}")
+
+        # figure out which permutation of the name GUID is being used 1 time
+        # then use it for all future rows
+        guid_name = "guid"
+        for name in ["guid", "GUID", "did", "DID"]:
+            if name in fieldnames:
+                guid_name = name
+
+        logging.debug(f"using {guid_name} to retrieve GUID to delete...")
+
+        for row in csvReader:
+            guid = row.get(guid_name)
+
+            if guid:
+                logging.debug(f"deleting GUID record:{guid}")
+                logging.debug(index.delete_record(guid=guid))
